@@ -19,12 +19,10 @@
 # The script must be able to look into "debian/rules" and deduce these exclusions.
 
 import os
-import re
 import sys
 import textwrap
 
 version = "";
-needs_cleanup = False
 packaged_by = "Matthias Klose <doko\@ubuntu.com>";
 common_licenses = {};
 
@@ -98,9 +96,9 @@ upstream_authors = [
 exclude_licenses = ["zlib.md", "pcsclite.md", "giflib.md", "libpng.md", "jpeg.md"]
 
 def print_field(name, single_line, value):
-  print(name + ":", end="")
+  print(name + ": ", end="")
   if (single_line):
-    print(" " + value)
+    print(value)
   else:
     print("\n" + value)
 
@@ -108,12 +106,12 @@ def print_header_stanza(format, files_excluded, source, comment):
   print_field("Format", True, format)
   print_field("Files-Excluded", False, files_excluded)
   print_field("Source", True, source)
-  print_field("Comment", False, comment)
+  print_field("Comment", True, comment)
   print() # an empty line
 
 def print_file_stanza(files, copyrights, license, comments):
   print_field("Files", True, files)
-  print_field("Copyright", False, copyrights)
+  print_field("Copyrights", False, copyrights)
   print_field("License", True, license) 
   if (comments is not None and len(comments) != 0):
     print_field("Comments", True, comments)
@@ -124,7 +122,8 @@ def generate_excluded_files_str():
 
 def generate_comment_str():
   upstream_authors_str = "\n      ".join(upstream_authors)
-  return f"""  Upstream Authors:
+  return f"""
+  Upstream Authors:
     OpenJDK:
       {upstream_authors_str}
     Packaged by:
@@ -133,7 +132,7 @@ def generate_comment_str():
 def generate_header_stanza():
   format = "https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/"
   excluded = generate_excluded_files_str()
-  source = "https://github.com/openjdk/jdk17u"
+  source = "https://github.com/openjdk/jdk"
   comment = generate_comment_str()
   print_header_stanza(format, excluded, source, comment)
 
@@ -167,7 +166,6 @@ def gen_comment(component):
 which may be included with JRE {version}, JDK {version} and OpenJDK {version}"""
 
 def gen_license_text(license):
-  print("Gathering license content for " + license, file=sys.stderr)
   component, content = get_content(license)
   component = component.split("## ")[1].rstrip("\n");
   return f"""
@@ -180,7 +178,7 @@ def gen_license_text(license):
 ------------------------------------------------------------------------------"""
 
     
-def gather_legal_dirs(path):
+def get_legal_dirs(path):
   legal_dirs = []
   for root, dirs, files in os.walk(path):
     if "legal" in dirs and (root.endswith("share") or root.endswith("unix")):
@@ -188,65 +186,33 @@ def gather_legal_dirs(path):
   return legal_dirs
 
 def gather_licenses(module):
-  legal_dirs = gather_legal_dirs(module)
+  legal_dirs = get_legal_dirs(module)
   licenses_text = ""
-  for dir in sorted(legal_dirs):
-    licenses = os.listdir(dir)
-    for license in sorted(licenses):
-      if not license in exclude_licenses:
-        licenses_text += gen_license_text(dir + "/" + license)
+  for dir in legal_dirs:
+    licenses = os.scandir(dir)
+    for license in licenses:
+      if not license.name in exclude_licenses:
+        licenses_text += gen_license_text(license.path)
   return licenses_text
 
 def gather_modules_licenses(srcdir):
   licenses = ""
-  modules = os.listdir(srcdir)
-  for module in sorted(modules):
-    licenses += gather_licenses(srcdir + "/" + module)
+  modules = os.scandir(srcdir)
+  for module in modules:
+    licenses += gather_licenses(module)
   return licenses
 
-def find_directory(prefix, path = '.'):
-  for file in os.scandir(path):
+def find_directory(prefix):
+  for file in os.scandir():
     if file.is_dir() and file.name.startswith(prefix):
       return file.path
-
-def search_source_rootdir(level, path = '.'):
-  # The user might have already pulled the source package.
-  # Search for a downloaded package at three levels
-  #  - openjdk
-  #  - openjdk/debian
-  #  - openjdk/debian/copyright-generator
-  # if one none found, download the source package
-  rootdir = find_directory(f"openjdk-{version}", path)
-  if rootdir is not None:
-    return rootdir
-
-  match level:
-    case 0:
-      path = "./debian"
-      level= level + 1
-    case 1:
-      path = "./debian/copyright-generator"
-      level = level + 1
-    case 2:
-      print("No source package found. Downloading...", file = sys.stderr)
-      os.system(f"pull-debian-source openjdk-{version} > /dev/null 2>&1")
-      needs_cleanup = True
-      return find_directory(f"openjdk-{version}")
-    case  _:
-      print("Irrecoverable error while searching for source package")
-      exit(1)
-
-  return search_source_rootdir(level, path)
-
+      
 def generate_copyright():
-  rootdir = search_source_rootdir(0)
-  if rootdir is None:
-    print("No source package found. Download also failed. Aborting.")
-    exit(2)
-  print(f"Using the source package at {rootdir}", file = sys.stderr)
+  os.system(f"pull-debian-source openjdk-{version} > /dev/null 2>&1")
+  rootdir = find_directory(f"openjdk-{version}")
   srcdir = f"{rootdir}/src"; 
 
-  os.system(f"/bin/sh ./debian/copyright-generator/strip-common-licenses.sh {rootdir} {version}")
+  os.system(f"/bin/sh strip-common-licenses.sh {rootdir} {version}")
   generate_header_stanza();
 
   licenses = f"""GPL with Classpath exception
@@ -263,31 +229,24 @@ The following licenses for third party code are taken from 'legal' \ndirectories
 
   print_file_stanza("*", "  " + "\n  ".join(openjdk_copyrights), fill_with_dots_and_indent(licenses), "")
   if (version != "11"):
-    print(open("./debian/copyright-generator/bundled-stanzas").read())
-  print(open("./debian/copyright-generator/debian-stanzas").read())
+    print(open("bundled-stanzas").read())
+  print(open("debian-stanzas").read())
 
   # clean-up
-  if needs_cleanup:
-    os.system(f"rm -rf *.debian.tar.xz *.orig.tar.xz *.dsc *googletest.tar.xz");
+  os.system(f"rm -rf {rootdir} *.debian.tar.xz *.orig.tar.xz *.dsc *googletest.tar.xz");
     
 
-
-def detect_version():
-  with open("debian/rules", 'r') as file:
-    content = file.read()
-    match = re.search(r'shortver\t=\s+(\d{2})', content)
-    if match:
-      return match.group(1)
-
 def main():
   global version
 
-  version = detect_version()
+  if (len(sys.argv) >= 1):
+    version = sys.argv[1]
 
-  sys.stdout = open('./debian/copyright', 'w')
-  supported_versions = ["11", "17", "21", "22", "23"]
-
-  if version in supported_versions:
+  if version == "" or version == "--help" or version == "-help" or version == "help":
+    print("Usage:\ncopyright-gen.py <version> > ../copyright")
+    print("version - 11 | 17 | 21 | 22")
+    print("Note: this script must be run from the `debian/copyright-generator` directory")
+  elif version == "11" or version == "17" or version == "21" or version == "22":
     generate_copyright()
   else:
     print("Version not supported.")
